==> roltrilinos-0.0.7.tar.gz: roltrilinos-0.0.7/setup.py <==
import os
import re
import sys
import platform
import subprocess

from setuptools import setup, Extension
from setuptools.command.build_ext import build_ext
from distutils.version import LooseVersion


class CMakeExtension(Extension):
    def __init__(self, name, sourcedir=''):
        Extension.__init__(self, name, sources=[])
        self.sourcedir = os.path.abspath(sourcedir)


class CMakeBuild(build_ext):
    def run(self):
        try:
            out = subprocess.check_output(['cmake', '--version'])
        except OSError:
            raise RuntimeError("CMake must be installed to build the following extensions: " +
                               ", ".join(e.name for e in self.extensions))

        if platform.system() == "Windows":
            cmake_version = LooseVersion(re.search(r'version\s*([\d.]+)', out.decode()).group(1))
            if cmake_version < '3.1.0':
                raise RuntimeError("CMake >= 3.1.0 is required on Windows")

        for ext in self.extensions:
            self.build_extension(ext)

    def build_extension(self, ext):
        extdir = os.path.abspath(os.path.dirname(self.get_ext_fullpath(ext.name)))
        install_path = os.path.join(extdir, ext.name)
        cmake_args = ['-DCMAKE_INSTALL_PREFIX:PATH=' + install_path,
                      '-DPYTHON_EXECUTABLE=' + sys.executable]

        cfg = 'Debug' if self.debug else 'Release'
        build_args = ['--config', cfg]

        if platform.system() == "Windows":
            cmake_args += ['-DCMAKE_LIBRARY_OUTPUT_DIRECTORY_{}={}'.format(cfg.upper(), extdir)]
            if sys.maxsize > 2**32:
                cmake_args += ['-A', 'x64']
            build_args += ['--', '/m']
        else:
            cmake_args += ['-DCMAKE_BUILD_TYPE=' + cfg]
            build_args += ['--', '-j2']

        cmake_args += ['-DBUILD_SHARED_LIBS=ON']
        cmake_args += ['-DTPL_ENABLE_MPI:BOOL=OFF']
        cmake_args += ['-DTrilinos_INSTALL_LIBRARIES_AND_HEADERS:BOOL=ON']
        cmake_args += ['-DTrilinos_ENABLE_ALL_OPTIONAL_PACKAGES:BOOL=OFF']
        cmake_args += ['-DTrilinos_ENABLE_TESTS:BOOL=OFF']
        cmake_args += ['-DTrilinos_ENABLE_ROL:BOOL=ON']
        cmake_args += ['-DTrilinos_ENABLE_EXPLICIT_INSTANTIATION:BOOL=ON']
        cmake_args += ['-DROL_ENABLE_STD_SHARED_PTR:BOOL=ON']
        cmake_args += ['-DROL_ENABLE_BOOST_PROPERTY_TREE:BOOL=ON']
        cmake_args += ['-DTrilinos_ENABLE_YouCompleteMe:Bool=ON']
        env = os.environ.copy()
        env['CXXFLAGS'] = '{} -DVERSION_INFO=\\"{}\\"'.format(env.get('CXXFLAGS', ''),
                                                              self.distribution.get_version())
        if not os.path.exists(self.build_temp):
            os.makedirs(self.build_temp)
        subprocess.check_call(['cmake', ext.sourcedir] + cmake_args, cwd=self.build_temp, env=env)
        subprocess.check_call(['cmake', '--build', '.', '--target', 'install'] + build_args, cwd=self.build_temp)

setup(
    name='roltrilinos',
    version='0.0.7',
    author='Drew Kouri, Denis Ridzal, Greg von Winckel',
    author_email='rol-developers@software.sandia.gov',
    description='A C++ package for large scale optimization.',
    long_description='',
    packages=['roltrilinos'],
    ext_modules=[CMakeExtension('roltrilinos')],
    cmdclass=dict(build_ext=CMakeBuild),
    zip_safe=False,
)

==> roltrilinos-0.0.8.tar.gz: roltrilinos-0.0.8/setup.py <==
import os
import re
import sys
import platform
import subprocess

from setuptools import setup, Extension
from setuptools.command.build_ext import build_ext
from distutils.version import LooseVersion


class CMakeExtension(Extension):
    def __init__(self, name, sourcedir=''):
        Extension.__init__(self, name, sources=[])
        self.sourcedir = os.path.abspath(sourcedir)


class CMakeBuild(build_ext):
    def run(self):
        try:
            out = subprocess.check_output(['cmake', '--version'])
        except OSError:
            raise RuntimeError("CMake must be installed to build the following extensions: " +
                               ", ".join(e.name for e in self.extensions))

        if platform.system() == "Windows":
            cmake_version = LooseVersion(re.search(r'version\s*([\d.]+)', out.decode()).group(1))
            if cmake_version < '3.1.0':
                raise RuntimeError("CMake >= 3.1.0 is required on Windows")

        for ext in self.extensions:
            self.build_extension(ext)

    def build_extension(self, ext):
        extdir = os.path.abspath(os.path.dirname(self.get_ext_fullpath(ext.name)))
        install_path = os.path.join(extdir, ext.name)
        cmake_args = ['-DCMAKE_INSTALL_PREFIX:PATH=' + install_path,
                      '-DPYTHON_EXECUTABLE=' + sys.executable]

        cfg = 'Debug' if self.debug else 'Release'
        build_args = ['--config', cfg]

        if platform.system() == "Windows":
            cmake_args += ['-DCMAKE_LIBRARY_OUTPUT_DIRECTORY_{}={}'.format(cfg.upper(), extdir)]
            if sys.maxsize > 2**32:
                cmake_args += ['-A', 'x64']
            build_args += ['--', '/m']
        else:
            cmake_args += ['-DCMAKE_BUILD_TYPE=' + cfg]
            build_args += ['--', '-j2']

        cmake_args += ['-DBUILD_SHARED_LIBS=ON']
        cmake_args += ['-DTPL_ENABLE_MPI:BOOL=OFF']
        cmake_args += ['-DTrilinos_INSTALL_LIBRARIES_AND_HEADERS:BOOL=ON']
        cmake_args += ['-DTrilinos_ENABLE_ALL_OPTIONAL_PACKAGES:BOOL=OFF']
        cmake_args += ['-DTrilinos_ENABLE_TESTS:BOOL=OFF']
        cmake_args += ['-DTrilinos_ENABLE_ROL:BOOL=ON']
        cmake_args += ['-DTrilinos_ENABLE_EXPLICIT_INSTANTIATION:BOOL=ON']
        cmake_args += ['-DROL_ENABLE_EXAMPLES:BOOL=OFF']
        cmake_args += ['-DROL_ENABLE_TESTS:BOOL=OFF']
        cmake_args += ['-DROL_ENABLE_Sacado:BOOL=OFF']
        cmake_args += ['-DROL_ParameterList:STRING=\"boost::property_tree\"']
        cmake_args += ['-DROL_Ptr:STRING=\"std::shared_ptr\"']
        cmake_args += ['-DTrilinos_ENABLE_YouCompleteMe:Bool=ON']
        env = os.environ.copy()
        env['CXXFLAGS'] = '{} -DVERSION_INFO=\\"{}\\"'.format(env.get('CXXFLAGS', ''),
                                                              self.distribution.get_version())
        if not os.path.exists(self.build_temp):
            os.makedirs(self.build_temp)
        subprocess.check_call(['cmake', ext.sourcedir] + cmake_args, cwd=self.build_temp, env=env)
        subprocess.check_call(['cmake', '--build', '.', '--target', 'install'] + build_args, cwd=self.build_temp)

setup(
    name='roltrilinos',
    version='0.0.8',
    author='Drew Kouri, Denis Ridzal, Greg von Winckel',
    author_email='rol-developers@software.sandia.gov',
    description='A C++ package for large scale optimization.',
    long_description='',
    packages=['roltrilinos'],
    ext_modules=[CMakeExtension('roltrilinos')],
    cmdclass=dict(build_ext=CMakeBuild),
    zip_safe=False,
)
